#!/bin/bash

#===============================================================================
#   icanhazip.sh    |   version 1.0 |   FreeBSD License    | 2013-04-02
#   James Hendrie   |   hendrie dot james at gmail dot com | someplacedumb.net
#===============================================================================

device="wlan0"

##  This determines what the last argument is (most portable)
##  (bash/ksh only:  ${@: -1})
##  (bash 3.x+ only:    ${!#})
if [ $# -gt 0 ]; then
    for i in $@; do :; done
    lastArg="$i"

    if [ ! $lastArg = "-h" ] && [ ! $lastArg = "-v" ] && \
        [ ! $lastArg = "-l" ] && [ ! $lastArg = "-r" ]; then

        device="$lastArg"
    fi
fi

function get_remote_address
{
    curl -s icanhazip.com
}

function get_local_address
{
    ifconfig $device | grep inet | head -n1 | tr -s ' ' | \
        cut -f3 -d' '
}


function print_help
{
    echo "This script will display your IP address.  By default, it will"
    echo "display both your remote (outside) IP address and your local address"
    echo -e "on the network.\n"
    echo "Usage:"
    echo -e "  icanhazip [option] [device]\n"
    echo "Options:"
    echo "  -h          :  Print this help"
    echo "  -v          :  Print version and author info"
    echo "  -l          :  Print only local address"
    echo "  -r or -o    :  Print only remote (outside) address"
    echo -e "  No args     :  Print both local and remote IP addresses\n"
    echo "Specify a device as the last argument to see local info for it.  This"
    echo "script defaults to wlan0 since that's what I use."
}

function print_version
{
    echo "icanhazip.sh version 1.0"
    echo "Written by James Hendrie (hendrie dot james at gmail dot com)"
    echo "'curl icanhazip.com' magicked up by SigFLUP, at locations unknown"
}

##  Get options
while getopts "hvlr" flag
do
    if [ $flag == 'h' ]; then
        print_help
        exit

    elif [ $flag == 'v' ]; then
        print_version
        exit

    elif [ $flag == 'l' ]; then
        echo "$(get_local_address)"
        exit

    elif [ $flag == 'r' ] || [ $flag == 'o' ]; then
        echo "$(get_remote_address)"
        exit
    fi
done

remoteAddress=$(get_remote_address)
localAddress=$(get_local_address)

echo "Remote address:  $remoteAddress"
echo "Local Address:   $localAddress"
